# -*- coding: utf-8 -*-

from prosegrinder import Word

def test_equality():
    w1 = Word('frowning', 2, True, False)
    w2 = Word('frowning', 2, True, False)
    w3 = Word('cafe', 2, True, False)
    assert(w1 == w2)
    assert(w1 != w3)
    assert(w2 != w3)



# -*- coding: utf-8 -*-

import re

import cmudict
import syllables

from prosegrinder.word import Word


class Dictionary():
    """A reference containing Words."""

    RE_NUMERIC = re.compile("^[+-]{0,1}\\d{1,3}(?:[,]\\d{3})*(?:[.]\\d*)*$")

    @staticmethod
    def normalize_text(text):
        return text.strip().lower()

    @staticmethod
    def is_numeric(word):
        return re.match(Dictionary.RE_NUMERIC, word) != None

    def __init__(self, cmudict=cmudict.dict()):
        self._cmudict = cmudict

    def syllable_count(self, word):
        syllable_count = 0
        if word in self._cmudict:
            phones = self._cmudict[word][0]
            # There's a more Pythonic way of doing this.
            for phone in phones:
                syllable_count += len(re.sub("[^012]", "", phone))
        elif self.is_numeric(word):
            syllable_count = len(re.sub('[^\\d\\+-]', '', word))
        else:
            syllable_count = syllables.estimate(word)
        return syllable_count

    @property
    def cmudict(self):
        return self._cmudict

    def get_word(self, word):
        normalized_word = self.normalize_text(word)
        syllable_count = self.syllable_count(normalized_word)
        is_dictionary_word = normalized_word in self._cmudict
        is_numeric = self.is_numeric(normalized_word)
        word = Word(normalized_word, syllable_count,
                    is_dictionary_word, is_numeric)
        return word



# -*- coding: utf-8 -*-

from os import path

from setuptools import setup

# Version
with open(path.join(path.dirname(__file__), 'prosegrinder', 'VERSION')) as version_file:
    VERSION = version_file.read().strip()
# Long Description
with open(path.join(path.dirname(__file__), 'README.rst')) as readme_file:
    LONG_DESCRIPTION = readme_file.read()


setup(
    name="prosegrinder",
    version=VERSION,
    url="https://github.com/prosegrinder/python-prosegrinder",

    author="David L. Day",
    author_email="dday376@gmail.com",

    description="A text analytics library for prose fiction.",
    long_description=LONG_DESCRIPTION,

    python_requires='>=3.4',
    packages=[
        'prosegrinder'
    ],
    package_dir={'prosegrinder': 'prosegrinder'},
    package_data={
        '': ['LICENSE', '*.rst', 'MANIFEST.in'],
    },
    include_package_data=True,

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)



# -*- coding: utf-8 -*-

from prosegrinder import Dictionary
from prosegrinder import Sentence

dictionary = Dictionary()
text = "This is a sentence of twelve words, and let's add some complexity."
sentence = Sentence(text, dictionary)

WORD_CHARACTER_COUNT = 53
WORD_COUNT = 12
SYLLABLE_COUNT = 16
COMPLEX_WORD_COUNT = 1

def test_sentence():
    assert(WORD_COUNT == sentence.word_count)
    assert(WORD_CHARACTER_COUNT == sentence.word_character_count)
    assert(SYLLABLE_COUNT == sentence.syllable_count)
    assert(COMPLEX_WORD_COUNT == sentence.complex_word_count)
